@@ -1091,9 +1091,18 @@ pygobject__g_instance_init(GTypeInstance   *instance,
           /* this looks like a python object created through
            * g_object_new -> we have no python wrapper, so create it
            * now */
-        wrapper = pygobject_new_full(object,
-                                     /*steal=*/ FALSE,
-                                     g_class);
+
+        if (g_object_is_floating (object)) {
+            g_object_ref (object);
+            wrapper = pygobject_new_full(object,
+                                         /*steal=*/ TRUE,
+                                         g_class);
+            g_object_force_floating (object);
+        } else {
+            wrapper = pygobject_new_full(object,
+                                         /*steal=*/ FALSE,
+                                         g_class);
+        }
 
         /* float the wrapper ref here because we are going to orphan it
          * so we don't destroy the wrapper. The next call to pygobject_new_full
@@ -1316,7 +1325,7 @@ pyg_type_register(PyTypeObject *class, const char *type_name)
 
     /* store pointer to the class with the GType */
     Py_INCREF(class);
-    g_type_set_qdata(instance_type, g_quark_from_string("PyGObject::class"),
+    g_type_set_qdata(instance_type, pygobject_class_key,
 		     class);
 
     /* Mark this GType as a custom python type */
