@@ -620,18 +620,18 @@ end:
             async_free_list = g_slist_prepend (async_free_list, closure);
             break;
         default:
-            g_error ("Invalid scope reached inside %s.  Possibly a bad annotation?",
-                     g_base_info_get_name (closure->info));
+            /* Handle new scopes added by gobject-introspection */
+            g_critical ("Unknown scope reached inside %s. Please file an issue "
+                        "at https://gitlab.gnome.org/GNOME/pygobject/issues/new",
+                        g_base_info_get_name (closure->info));
     }
 
     _invoke_state_clear (&state);
     PyGILState_Release (py_state);
 }
 
-void _pygi_invoke_closure_free (gpointer data)
+void _pygi_invoke_closure_free (PyGICClosure* invoke_closure)
 {
-    PyGICClosure* invoke_closure = (PyGICClosure *) data;
-
     g_callable_info_free_closure (invoke_closure->info,
                                   invoke_closure->closure);
 
@@ -651,7 +651,7 @@ _pygi_make_native_closure (GICallableInfo* info,
                            PyGIClosureCache *cache,
                            GIScopeType scope,
                            PyObject *py_function,
-                           gpointer py_user_data)
+                           PyObject *py_user_data)
 {
     PyGICClosure *closure;
     ffi_closure *fficlosure;
